PaRe-package: PaRe: A Way to Perform Code Review or QA on Other Packages
Description
Reviews other packages during code review by looking at their dependencies, code style, code complexity, and how internally defined functions interact with one another.