Learn R Programming

PaRe (version 0.1.16)

checkDependencies: checkDependencies

Description

Check package dependencies

Usage

checkDependencies(repo, dependencyType = c("Imports", "Depends"), nThreads = 1)

Value

(data.frame())

Data frame with all the packages that are now permitted.

columndata type
packagecharacter()
versioncharacter()

Arguments

repo

(Repository)
Repository object.

dependencyType

(character())
Types of dependencies to be included

nThreads

(numeric(1): 1) Number of threads to use to fetch permitted packages

Examples

Run this code
# \donttest{
# Set cahce, usually not required.
withr::local_envvar(
  R_USER_CACHE_DIR = tempfile()
)

fetchedRepo <- tryCatch(
  {
    # Set dir to clone repository to.
    tempDir <- tempdir()
    pathToRepo <- file.path(tempDir, "glue")

    # Clone repo
    git2r::clone(
      url = "https://github.com/tidyverse/glue.git",
      local_path = pathToRepo
    )

    # Create instance of Repository object.
    repo <- PaRe::Repository$new(path = pathToRepo)

    # Set fetchedRepo to TRUE if all goes well.
    TRUE
  },
  error = function(e) {
    # Set fetchedRepo to FALSE if an error is encountered.
    FALSE
  },
  warning = function(w) {
    # Set fetchedRepo to FALSE if a warning is encountered.
    FALSE
  }
)

if (fetchedRepo) {
  # Use checkDependencies on the Repository object.
  checkDependencies(repo)
  checkDependencies(repo, dependencyType = c("Imports", "Suggests"))
}
# }

Run the code above in your browser using DataLab